@@ -1,17 +1,16 @@
 //! List all contracts
 use crate::{util, Result, Storage};
-use ceres_runtime::Metadata;
+use ceres_support::types::Metadata;
+use parity_scale_codec::Decode;
 
 /// List all contracts
 pub fn exec(store: &Storage) -> Result<()> {
     let mut contracts: Vec<Metadata> = Vec::new();
-    for r in store.0.iter() {
+    for r in store.db.iter() {
         let (k, v) = r?;
         if k.len() == 32 {
-            continue;
+            contracts.push(Metadata::decode(&mut v.as_ref())?);
         }
-
-        contracts.push(bincode::deserialize(&v)?);
     }
 
     let mut output: String = format!("\n\t{} {}\n", util::pad("contract", 20), "code-hash");
